@@ -4,7 +4,7 @@ from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.template.defaultfilters import urlencode
 
-import lxml.html
+from lxml import html, etree
 
 
 SAFE_EXTERNAL_LINK_PATTERNS = getattr(settings, 'SAFE_EXTERNAL_LINK_PATTERNS', ())
@@ -21,18 +21,18 @@ class RewriteExternalLinksMiddleware(object):
 
         external_link_root = reverse('external_link', kwargs={'link': ''})
 
-        if "text" in response['Content-Type'] and not request.META.get('PATH_INFO').startswith(external_link_root):
+        if "text" in response['Content-Type'] and not request.META.get('PATH_INFO').startswith(external_link_root) and response.content:
             next = str(request.path)
 
-            html = lxml.html.document_fromstring(response.content)
-            for element, attribute, link, pos in html.iterlinks():
+            document_content = html.document_fromstring(response.content)
+            for element, attribute, link, pos in document_content.iterlinks():
                 # I only care about a tags with an href that is external
                 if element.tag == "a" and attribute == "href" and re.match(r'^http(s?):\/\/', link):
                     if re.match(safe_urls, link):
                         continue
                     element.set('href', '%(root)s%(link)s?next=%(next)s' % {'root': external_link_root, 'link': urlencode(link, safe=''), 'next': next})
 
-            response.content = lxml.html.tostring(html)
+            response.content = html.tostring(document_content)
             return response
         else:
             return response
